@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Switcher unofficial integration device module."""
+"""Switcher integration device module."""
 
 from abc import ABC
 from dataclasses import dataclass, field
@@ -144,6 +144,11 @@ class SwitcherTimedBase(ABC):
 
     remaining_time: str
     auto_shutdown: str
+        
+    @property
+    def auto_off_set(self) -> str:
+        """Fix for backward compability issues with home assistant."""
+        return self.auto_shutdown
 
 
 @final
